*acq4
/*compute theoretical autocorrelations of q and s
differs from acq3 in that extra information about by var4 is passed from input to output (though not used)


See notes 3/23/02.

Weights in Taylor rule are "gamma" (e.g., gammapi is weight on inflation)
In weights and variables names, "twid" means differences between countries
        for example xpitwid = xpi(t) - xpi*(t)
d(t) is exchange rate risk premium

Fundamentals follow:
    Z(t)=phi*Z(t-1)+ez
        Z(t) has nphi elements
        When monthly expected inflation is in mrule
          nphi = nfund*nlags
                nfund = number of distinct fundamentals
                nlags = number of lags in the VAR
        When annual expected inflation is in mrule
          nphi = nfund*nlags + (12-nlags)
          Z(t) is supplemented with pi(t-nlags) ... pi(t-11) so that annual inflation is a lin.
             comb. of elements of Z(t)
        E[ez*ez'] = varZe
        E[ZZ'] = varZ
    phimonth, varZemonth are smaller dimension VARs in monthly data used in estimation of VAR
          phi and varZe have 1s and 0s added to account for presence of lags of pi(t)
q(t) = real exchange rate
q(t) = s(t) - p(t) + p*(t), s(t)= nominal exchange rate
Model is
        q(t) = bdisct*z(t) + bdisct*E(t)q(t+1)
                0<bdisct<1
                z(t) = cz'Z(t)
                  cz = (nfund x 1) vector
                  cz = expected_pi + czpi + czy
                        expected_pi = E(t)[p(t+1)-p(t)]
                        czpi = -gammapitwid*E(t)[p(t+12)-p(t)] 
                        czy = -gammaytwid*y(t)

        **new in acq<n>: to compute cz, have to compute E(t)[p(t+nseas)-p(t)], where
                 E(t)[p(t+nseas)-p(t)] = cpiannual'*[phi**nseas]Z(t) = cpiannual_mrule'Z(t)

Then
        q(t) = bdisct*cz'Ibphi*Z(t) = cq'Z(t)
                Ibphi = inv(I-b*phi)
                cq = (nfund x 1) vector
Let
        cpitwid'Z(t) = pi(t) - pi*(t) = p(t)-p(t-1) - [p*(t)-p*(t-1)]
Since
        ds(t) = dq(t) + pitwid(t)
we have
        ds(t) = cds0'Z(t) + cds1'Z(t-1)
                cds0 = cq + cpitwid, cds1 = -cq

So moments of q(t) and s(t)
        Eq(t)q(t-j) = cq'[phi**j]*VarZ*cq
        var[ds(t)] = cds0'varZ*cds0 + cds0'phi*varZ*cds1 + cds1'varZ*phi'cds0 + cds1'varZ*cds1
        j>0 Eds(t)ds(t-j) = cds0'varZ*cds0 + cds0'[phi**(j+1)]*varZ*cds1 +
                        cds1'[phi**(j-1)]*varZ*cds0 + cds1'[phi**j]*varZ*cds1
Or, letting Zcov(j) = EZ(t)Z(t-j)'
        var(ds) = cds0'varZ*cds0 + 2*cds0'Zcov(1)*cds1 + cds1'varZ*cds1
        j>0 Eds(t)ds(t-j) = cds0'Zcov(j)*cds0 + cds0'Zcov(j+1)*cds1 +
                        cds1'Zcov(j-1)*cds0 + cds1'Zcov(j)cds1

Flags and variables introduced to handle the possibility that annual inflation appears in money rule:
For AR(1), Z(t) is ordered something like

   [pi(t) y(t) pi(t-1) ... pi(t-11)]'  (nlags=1)

or

   [pi(t) pi(t-1) y(t) y(t-1) pi(t-2) ... pi(t-11)]'  (nlags=2)

where u(t) and d(t) may or may not be present

   
   nseas = number of seasons in a year = 12
   phimonth and varZemonth apply to the system in monthly inflation and output
       nfundmonth = dimension of phimonth and varZemonth
   phi and varZe have 1s and 0s added to account for presence of lags of pi(t)
   vectors related to inflation
        cpi_mule'Z(t) = E(t)pi(t+1) = E(t)[p(t+1)-p(t)]
        cpiannual_mule'Z(t) = E(t)[p(t+12)-p(t)]
        cpiannual'Z(t) = [p(t+12)-p(t)]
        cpi_e_month = same as cpi_annual_mrule, but drops trailing zeros that correspond to
                  pi(t-nlags) ... pi(t-11).

*/
environment columns=132
alloc 30 1000
clear
cal 1959 1 12
*
***
*
decl int nfund nphi nfundmonth nphimonth
decl real gammapi gammay gammapistar gammaystar gammapitwid gammaytwid gammaq
decl int nfundmonth nlags ndeterm ibaseyear ibasemo ilastyear ilastmo nseas
decl int ippi ipy ippistar ipystar ippitwid ipytwid ipu ipd
decl int jppi jpy jppistar jpystar jppitwid jpytwid jpu jpd
decl label country date1 date2
decl string variablename string1 string2 string3 paramname
decl vect[label] varnames
comp nseas=12
*
open data acq4.inp
read(unit=data) country
read(unit=data) string1
read(unit=data) nfundmonth ndeterm nlags ibaseyear ibasemo ilastyear ilastmo
read(unit=data) string1
dim varnames(nfundmonth)
read(unit=data) varnames
read(unit=data) variablename
comp nphimonth = nfundmonth*nlags
*tempphi includes space for deterministic terms
decl rect phimonth(nfundmonth,nphimonth) tempphi(nfundmonth,nphimonth+ndeterm)
decl sym varZemonth(nfundmonth,nfundmonth) varZmonth(nfundmonth,nfundmonth)
read(unit=data) string1
read(unit=data) ippi ipy ippistar ipystar ippitwid ipytwid
read(unit=data) string1
read(unit=data) varZemonth
read(unit=data) string1
read(unit=data) tempphi
read(unit=data) gammapi gammay gammapistar gammaystar gammapitwid gammaytwid gammaq
read(unit=data) paramname
close data
do irow=1,nfundmonth
  do icol=1,nphimonth
    comp phimonth(irow,icol) = tempphi(irow,icol)
  end do
end do
comp ipu=0, ipd=0
*this assumes nlags<=nseas
  comp nphi=nlags*nfundmonth + (nseas-nlags)
write(noskip,format='(1x,16(f6.2,1x))') phimonth
*
comp nvcv=6
decl rect phi(nphi,nphi) Ibphi(nphi,nphi) bphi(nphi,nphi)
decl sym varZe(nphi,nphi) varZ(nphi,nphi)
decl vect cq(nphi) cz(nphi) cds0(nphi) cds1(nphi) cnull(nphi)
decl vect cytwid(nphi) cpitwid(nphi) cd(nphi) cu(nphi)
decl vect ci(nphi) cpi(nphi) cpistar(nphi) cy(nphi) cystar(nphi) cpiannual(nphi)
decl vect cpi_mrule(nphi) cpistar_mrule(nphi) cpitwid_mrule(nphi) cpiannual_mrule(nphi)
decl vect cpi_e_month(nphimonth)
*decl real phipi phipistar phipitwid phiy phiystar phiytwid
decl real phiu phiustar phiutwid phid
*pointers into Z(t)
decl int ipu ipd
*pointers into contemporaneous variance covariance matrix of (i,q,dq,ds,pitwid,ytwid)
decl int ivcvi ivcvq ivcvdq ivcvds ivcvpi ivcvy
decl sym vcvnow(nvcv,nvcv) vcvcorr(nvcv,nvcv)
decl vect[vect] c0(nvcv) c1(nvcv)
decl vect[labels] vnames(nvcv)
comp nmoment=5
decl vect qcov(nmoment) dscov(nmoment) qcorr(nmoment) dscorr(nmoment) intcov(nmoment) intcorr(nmoment)
decl vect dqcov(nmoment) dqcorr(nmoment)
decl vect epicov(nmoment) epicorr(nmoment)
decl vect depicov(nmoment) depicorr(nmoment)
decl real qvar dqvar dsvar ivar epivar depivar
decl vect[rect] Zcov(nmoment)
*
procedure makejp ipnow jpnow
type int ipnow *jpnow
*ipnow is pointer into set of variables in the VAR, jpnow is pointer when VAR is written in companion form
if ipnow .eq. 0
  comp jpnow=0
else
  comp jpnow=(ipnow-1)*nlags+1
return
end
*
procedure makebig vZe Zphi vZemonth Zphimonth
type sym *vZe vZemonth
type rect *Zphi Zphimonth
* set up pointers into Z(t)
execute makejp ippi jppi
execute makejp ippistar jppistar
execute makejp ippitwid jppitwid
execute makejp ipy jpy
execute makejp ipystar jpystar
execute makejp ipytwid jpytwid
execute makejp ipu jpu
execute makejp ipd jpd
comp vZe = %const(0.), Zphi=%const(0.), cpiannual=%const(0.)
*this loop writes the system as a first order VAR
do ifund=1,nfundmonth
  comp irowbase = (ifund-1)*nlags+1
  comp vZe(irowbase,irowbase) = varZemonth(ifund,ifund)
  do jfund = 1,ifund-1
     comp icolnow = (jfund-1)*nlags+1
     comp vZe(icolnow,irowbase) = varZemonth(jfund,ifund)
  end do
  do icol=1,nphimonth
    comp Zphi(irowbase,icol) = Zphimonth(ifund,icol)
  end do icol
  do irow=1,nlags-1
     comp Zphi(irowbase+irow,irowbase+irow-1) = 1.
  end do irow
end do ifund
do ilag=1,nlags
   comp cpiannual(jppitwid+ilag-1) = 1.
end do
* now put in enough additional lags of pi so that annual inflation can be computed by summing monthly inflation
*  comp irowbase = (nfundmonth-1)*nphimonth+1
  comp irowbase = nphimonth+1
  comp icolbase = (ippitwid-1)*nlags + nlags
  comp Zphi(irowbase,icolbase)=1.
  comp cpiannual(irowbase)=1.
  comp icolbase = irowbase-1
  disp "irowbase icolbase" irowbase icolbase
  do ilag=1,nseas-nlags-1
     comp Zphi(irowbase+ilag,icolbase+ilag)=1.
     comp cpiannual(irowbase+ilag)=1.
  end do
*/
disp "makebig: cpiannual"
write(noskip,format='(1x,16(f6.2,1x))') cpiannual
disp "makebig: vZe"
write(noskip,format='(1x,16(f6.2,1x))') vZe
disp "makebig: Zphi"
write(noskip,format='(1x,16(f6.2,1x))') Zphi
*
return
end
*
procedure makecpi_mrule Zphi cpi cpi_month
type rect Zphi
type vect *cpi *cpi_month
local rect phiseas
comp phiseas=Zphi
do iloop=1,nseas-1
  comp phiseas=phiseas*Zphi
end do
disp "makecpi_mrule: phiseas"
write(noskip,format='(1x,16(f7.2,1x))') phiseas
comp cpi = tr(phiseas)*cpiannual
comp cpi_month = %const(0.)
do ii=1,nphimonth
  comp cpi_month(ii) = cpi(ii)
end do
*
return
end
*
procedure zmoment vZ vZe Zphi covZ
*compute VCV of Z, given AR matrix Zphi and VCV of innovations vZe
type sym *vZ *vZe
type vect[rect] *covZ
type rect Zphi
comp vZ = %psdinit(Zphi,vZe)
comp covZ(1) = Zphi*vZ
do icov=2,nmoment
  comp covZ(icov) = Zphi*covZ(icov-1)
end do
return
end
*
procedure makec Zphi
type rect Zphi
local rect phiseas
*"ip____" are indexes into Z(t), set to 0 if the variable is not included
* pitwid = pi-pistar, ytwid = y-ystar, which explains why signs flip on pistar and ystar
comp cpitwid = %const(0.), cytwid = %const(0.), cnull=%const(0.)
comp cd = %const(0.), cu = %const(0.)
comp ci = %const(0.), cpi = %const(0.), cpistar=%const(0.)
comp cy = %const(0.), cystar=%const(0.)
if ippitwid .ne. 0
  comp cpitwid(jppitwid) = 1.
if ippi .ne. 0
  comp cpitwid(jppi) = 1., cpi(jppi) = 1.
if ippistar .ne. 0
  comp cpitwid(jppistar) = -1., cpistar(jppistar) = 1.
if ipytwid .ne. 0
  comp cytwid(jpytwid) = 1.
if ipy .ne. 0
  comp cytwid(jpy) = 1., cy(jpy) = 1.
if ipystar .ne. 0
  comp cytwid(jpystar) = -1., cystar(jpystar) = 1.
if ipu .ne. 0
  comp cu(jpu) = 1.
if ipd .ne. 0
  comp cd(jpd) = 1.
comp cpi_mrule = tr(Zphi)*cpi
comp cpistar_mrule = tr(Zphi)*cpistar
comp cpitwid_mrule = tr(Zphi)*cpitwid
*if annual inflation is in mon. policy rule, assume pitwid
   execute makecpi_mrule Zphi cpiannual_mrule cpi_e_month
disp "makec: cpiannual cpiannual_mrule"
write(noskip,format='(1x,16(f7.2,1x))') cpiannual cpiannual_mrule
*
return
end
*
procedure makecz cz Zphi
type vect *cz
type rect Zphi
local vect expected_pi czpi czy
dim expected_pi(nphi) czpi(nphi) czy(nphi)
comp cz = %const(0.), czpi = %const(0.), czy = %const(0.)
comp expected_pi = tr(Zphi)*cpitwid
*the following allows for just pitwid, both pi and pistar, and (though I can't see using this)
*  pitwid along with either pi and pistar.  (Actually, the code allows for all three, but that would
*  be a singular system.)  Ditto for ytwid, y, ystar.
*probably this code should use c__mrule
if ippitwid .ne. 0
   comp czpi(jppitwid) =  czpi(jppitwid) - gammapitwid
if ippi .ne. 0
   comp czpi(jppi) =  czpi(jppi) - gammapi
if ippistar .ne. 0
   comp czpi(jppistar) =  czpi(jppistar) + gammapistar
*
if ipytwid .ne. 0
   comp czy(jpytwid) =  czy(jpytwid) - gammaytwid
if ipy .ne. 0
   comp czy(jpy) =  czy(jpy) - gammay
if ipystar .ne. 0
   comp czy(jpystar) =  czy(jpystar) + gammaystar
*expected inflation is in m rule
*if annual inflation is in mrule, code as of present does not allow separate coefficients in pi and pistar
   comp czpi = -gammapitwid*cpiannual_mrule
*
comp cz = expected_pi + czpi + czy - cu + cd
disp "makecz: expected_pi czpi, czy"
write(noskip,format='(1x,16(f7.2,1x))') expected_pi czpi czy
*
return
end
*
procedure makecq cq cz Zphi bdisct
type vect *cq cz
type rect Zphi
type real bdisct
local rect bphi cqtemp
dim bphi(nphi,nphi)
comp bphi = %identity(nphi) - bdisct*Zphi
comp Ibphi = inv(bphi)
comp cqtemp = bdisct*tr(cz)*Ibphi
comp cq = tr(cqtemp)
disp "makecq: I-b*phi"
write(noskip,format='(1x,16(f7.2,1x))') bphi
disp "makecq: inv(I-b*phi) ="
write(noskip,format='(1x,16(f7.2,1x))') Ibphi
return
end
*
procedure makecds cds0 cds1 cq cpitwid
type vect *cds0 *cds1 cpitwid
type vect cq
comp cds0 = cq + cpitwid
comp cds1 = (-1.)*cq
return
end
*
procedure unicorr cx0 cx1 vZ covZ varx covx corrx
*compute variance, autocovariances and autocorrelations for the variable
*  x = cx0'Z(t) + cx1'Z(t-1)
*cx1 might be zero
type vect *covx *corrx
type vect cx0 cx1
type vect[rect] covZ
type sym vZ
type real *varx
local rect xtemp xtemp1 xtemp2 xtemp3 xtemp4
*
comp xtemp1 = tr(cx0)*covZ(1)*cx1
comp xtemp2 = %qform(vZ,cx0) + %qform(vZ,cx1)
comp xtemp3 = xtemp2 + 2.*xtemp1
comp varx = xtemp3(1,1)
disp "var(x): xtemp1,2" xtemp1(1,1) xtemp2(1,1)
*
comp xtemp1 = tr(cx0)*covZ(1)*cx0
comp xtemp2 = tr(cx0)*covZ(2)*cx1
comp xtemp3 = tr(cx1)*vZ*cx0
comp xtemp4 = tr(cx1)*covZ(1)*cx1
comp xtemp = xtemp1 + xtemp2 + xtemp3 + xtemp4
disp "xcov(1): xtemp1,2,3,4" xtemp1(1,1) xtemp2(1,1) xtemp3(1,1) xtemp4(1,1)
comp covx(1) = xtemp(1,1)
comp corrx(1) = covx(1)/varx
comp ncov = %rows(covx)
do icov=2,ncov-1
  comp xtemp1 = tr(cx0)*covZ(icov)*cx0
  comp xtemp2 = tr(cx0)*covZ(icov+1)*cx1
  comp xtemp3 = tr(cx1)*covZ(icov-1)*cx0
  comp xtemp4 = tr(cx1)*covZ(icov)*cx1
  comp xtemp = xtemp1 + xtemp2 + xtemp3 + xtemp4
  comp covx(icov) = xtemp(1,1)
  comp corrx(icov) = covx(icov)/varx
end do
*
return
end
*
procedure makeci ci
type vect *ci
local vect citemp1 citemp2 citemp3
*
*i = gammaq*q + gammapi*E(t)pi + gammay*y + u
  comp ci = gammaq*cq + gammapitwid*cpiannual_mrule + gammaytwid*cytwid + cu
*using E(t)s(t+1)-s(t)+d(t)=i(t), check calculation
comp citemp1 = tr(phi)*cds0
comp citemp2 = citemp1 + cds1 + cd
comp citemp3 = citemp2 - ci
disp "makeci: cds0 citemp1 citemp2 cds1 cd"
write(noskip,format='(1x,16(f7.2,1x))') cds0
write(noskip,format='(1x,16(f7.2,1x))') citemp1
write(noskip,format='(1x,16(f7.2,1x))') citemp2
write(noskip,format='(1x,16(f7.2,1x))') cds1
write(noskip,format='(1x,16(f7.2,1x))') cd
disp "citemp3: should be zero"
write(noskip,format='(1x,16(f7.2,1x))') citemp3
return
end
*
procedure crosscov cx0 cx1 ca0 ca1 vZ covZ covxa
*compute cross covariances of x and a, where
*  x = cx0'Z(t) + cx1'Z(t-1), a = ca0'Z(t) + ca1'Z(t-1)
*cx1 and ca1 might be zero
type vect cx0 cx1 ca0 ca1
type vect[rect] covZ
type sym vZ
type real *covxa
local rect xtemp xtemp1 xtemp2 xtemp3 xtemp4
*
comp xtemp1 = tr(cx0)*vZ*ca0
comp xtemp2 = tr(cx0)*covZ(1)*ca1
comp xtemp3 = tr(cx1)*tr(covZ(1))*ca0
comp xtemp4 = tr(cx1)*vZ*ca1
comp xtemp = xtemp1 + xtemp2 + xtemp3 + xtemp4
comp covxa = xtemp(1,1)
disp "crosscov: xtemp1,2,3,4" xtemp1(1,1) xtemp2(1,1) xtemp3(1,1) xtemp4(1,1)
*
return
end
*
procedure vcvall vcvnow vcvcorr vZ covZ
type sym *vcvnow *vcvcorr vZ
type vect[rect] covZ
local real covxa
*
comp c0(ivcvi) = ci, c1(ivcvi) = cnull
comp c0(ivcvq) = cq, c1(ivcvq) = cnull
comp c0(ivcvdq) = cq, c1(ivcvdq) = cds1
comp c0(ivcvds) = cds0, c1(ivcvds) = cds1
comp c0(ivcvpi) = cpitwid, c1(ivcvpi) = cnull
comp c0(ivcvy) = cytwid, c1(ivcvy) = cnull
disp "vcvall: c0"
write(noskip,format='(1x,16(f7.2,1x))') c0
disp "vcvall: c1"
write(noskip,format='(1x,16(f7.2,1x))') c1
*
do iv=1,nvcv
  do jv=1,iv
    execute crosscov c0(iv) c1(iv) c0(jv) c1(jv) vZ covZ vcvnow(iv,jv)
  end do
end do
comp vcvcorr = vcvnow
do iv=1,nvcv
   do jv=1,iv-1
      comp vcvcorr(iv,jv) = vcvnow(iv,jv)/(sqrt(vcvnow(iv,iv)*vcvnow(jv,jv)))
   end do
end do
*
return
end
*********************************************************************************
*********************
*
*
comp bdisct = 1./(1.+gammaq)
disp gammapi gammay gammapistar gammaystar gammapitwid gammaytwid gammaq bdisct paramname
disp ippi ipy ippistar ipystar ippitwid ipytwid ipu ipd
write(noskip,format='(1x,16(f6.2,1x))') varZemonth
write(noskip,format='(1x,16(f6.2,1x))') phimonth
if ipu .ne. 0; begin
  *adjust varZe and phi so that (1)innovation in phi is uncorrelated w/ other
  *innovations, (2)AR(1) parameter for phi=phiu, with variance of innovation adjusted
  *to keep var(u) constant
  comp varZemonth(ippitwid,ipu)=0., varZemonth(ipytwid,ipu)=0.
  comp phitemp=phimonth(ipu,ipu)
  comp varu = varZemonth(ipu,ipu)/(1.-phitemp*phitemp)
  comp varZemonth(ipu,ipu) = varu*(1.-phiu*phiu)
  comp phimonth(ipu,ipu) = phiu
  comp varZemonth(ipu,ipu)=0.
  write(noskip,format='(1x,16(f7.2,1x))') varZemonth
  write(noskip,format='(1x,16(f7.2,1x))') phi
end begin
end if
*
execute makebig varZe phi varZemonth phimonth
execute zmoment varZ varZe phi Zcov
write(noskip,format='(1x,16(f7.2,1x))') varZ
*do imoment=1,nmoment
do imoment=1,2
  disp "cov at lag " imoment
  write(noskip,format='(1x,16(f7.2,1x))') Zcov(imoment)
end do
execute makec phi
write(noskip,format='(1x,20(f2.0,1x))') cpitwid cytwid cd cu
write(noskip,format='(1x,20(f2.0,1x))') cpi cpistar cy cystar
write(noskip,format='(1x,16(f7.2,1x))') cpi_mrule cpistar_mrule cpitwid_mrule
execute makecz cz phi
write(noskip,format='(1x,16(f7.2,1x))') cz
execute makecq cq cz phi bdisct
write(noskip,format='(1x,16(f7.2,1x))') cq
*
input ivcvi ivcvq ivcvdq ivcvds ivcvpi ivcvy
         1    2      3      4      5      6
comp vnames(ivcvi) = "i", vnames(ivcvq) = "q", vnames(ivcvdq)="dq"
comp vnames(ivcvds) = "ds", vnames(ivcvpi) = "pi", vnames(ivcvy)="y"
execute unicorr cq cnull varZ Zcov qvar qcov qcorr
disp qvar sqrt(qvar)
write(noskip,format='(1x,16(f7.2,1x))') qcov qcorr
execute makecds cds0 cds1 cq cpitwid
write(noskip,format='(1x,16(f7.2,1x))') cds0 cds1
execute unicorr cds0 cds1 varZ Zcov dsvar dscov dscorr
disp dsvar sqrt(dsvar) qvar sqrt(qvar)
write(noskip,format='(1x,16(f7.2,1x))') dscov dscorr qcorr
execute makeci ci
write(noskip,format='(1x,16(f7.2,1x))') ci
execute unicorr ci cnull varZ Zcov ivar intcov intcorr
disp ivar sqrt(ivar)
write(noskip,format='(1x,16(f7.2,1x))') intcov intcorr
execute unicorr cq cds1 varZ Zcov dqvar dqcov dqcorr
disp dqvar sqrt(dqvar)
write(noskip,format='(1x,16(f7.2,1x))') dqcov dqcorr
*added for the paper
execute unicorr cpiannual_mrule cnull varZ Zcov epivar epicov epicorr
write(noskip,format='(1x,16(f7.2,1x))') epicov epicorr
comp cpi_lag = (-1.)*cpiannual_mrule
execute unicorr cpiannual_mrule cpi_lag varZ Zcov depivar depicov depicorr
write(noskip,format='(1x,16(f7.2,1x))') depicov depicorr
comp vcvnow=%const(0.), vcvcorr=%const(0.)
execute vcvall vcvnow vcvcorr varZ Zcov
write(noskip,format='(1x,16(f7.2,1x))') vcvnow
write(noskip,format='(1x,16(f7.2,1x))') vcvcorr
*
open copy acq4.out
disp(unit=copy) country
disp(unit=copy) "no. of fundamentals, deterministic terms, lags in VAR; flag for annual pi in m rule, no. seasons, start and end date:"
disp(unit=copy) nfundmonth ndeterm nlags nseas ibaseyear ibasemo ilastyear ilastmo
disp(unit=copy) varnames
disp(unit=copy) variablename
disp(unit=copy) $
"      gammapi       gammay      gammapistar gammaystar      gammapitwid    gammaytwid     gammaq        bdisct"
disp(unit=copy) gammapi gammay gammapistar gammaystar gammapitwid gammaytwid gammaq bdisct paramname
disp(unit=copy) "parameter_set_name"
disp(unit=copy) paramname
disp(unit=copy) "   jppi  jpy  jppistar jpystar jppitwid jpytwid   jpu     jpd"
disp(unit=copy) ###### jppi jpy jppistar jpystar jppitwid jpytwid jpu jpd
disp(unit=copy) "cpi_e_month cz cq ci"
write(unit=copy,noskip,format='(1x,16(f8.4,1x))') cpi_e_month
write(unit=copy,noskip,format='(1x,16(f8.4,1x))') cz
write(unit=copy,noskip,format='(1x,16(f8.4,1x))') cq
write(unit=copy,noskip,format='(1x,16(f8.4,1x))') ci
disp(unit=copy) "phi for VAR (deterministic terms in last column(s))"
write(noskip,unit=copy,format='(1x,16(f8.4,1x))') tempphi
disp(unit=copy) "VCV for VAR"
write(noskip,unit=copy,format='(1x,16(f8.4,1x))') varZemonth
/*
disp(unit=copy) "varZe"
write(noskip,unit=copy,format='(1x,16(f8.4,1x))') varZe
disp(unit=copy) "phi "
write(noskip,unit=copy,format='(1x,16(f8.4,1x))') phi
*/
disp(unit=copy) $
"      var(ds)        sd(ds)        var(q)       sd(q)          var(dq)      sd(dq)        var(i)        sd(i)"
disp(unit=copy) dsvar sqrt(dsvar) qvar sqrt(qvar) dqvar sqrt(dqvar) ivar sqrt(ivar)
disp(unit=copy) "dscov dscorr"
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') dscov dscorr
disp(unit=copy) "qcorr qcov dqcov dqcorr"
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') qcorr qcov dqcov dqcorr
disp(unit=copy) "iccov idcorr"
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') intcov intcorr
disp(unit=copy) "cross-correlations"
disp(unit=copy) @5 vnames(1)  @15 vnames(2) @25 vnames(3) @35 vnames(4) @45 vnames(5) @55 vnames(6)
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') vcvcorr
disp(unit=copy) "autocovariances and autocorrelations of expected annual inflation, variance= " epivar
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') epicov epicorr
disp(unit=copy) "autocovariances and autocorrelations of change in expected ann infl, variance= " depivar
write(unit=copy,noskip,format='(1x,16(f7.2,1x))') depicov depicorr
disp(unit=copy) "autocorrelations in form suitable for including in tables in paper"
disp(unit=copy) "Lag            q        dq      ds"
do i=1,3
   disp(unit=copy) ## i @15 #.## qcorr(i) @25 #.## dqcorr(i) @35 #.## dscorr(i)
end do
close copy
*
end
end
end
